.. image:: https://img.shields.io/badge/licence-AGPL--3-blue.svg
    :alt: License: AGPL-3

Serasa Crednet
===========================

Este modulo é responsável por realizar a pesquisa do CPF ou CNPJ do cliente junto ao Serasa utilizando o produto Crednet.

Configuration
=============

É imprescindível que os clientes cadastrados possuam um número de CPF ou CNPJ para a realização da consulta.


Credits
=======

Contributors
------------
- KMEE
- Luiz Felipe do Divino


Maintainer
----------

This module is maintained by the KMEE. http://www.kmee.com.br
